from .extension import Tailwind

__all__ = ["Tailwind"]
